ChatGptReferenceImage class sealed

Implementers
Annotations
  • @freezed

Constructors

ChatGptReferenceImage.fileId({required String fileId})
const
factory
ChatGptReferenceImage.url({required String url})
const
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>({required TResult url(ChatGptReferenceImage_Url value), required TResult fileId(ChatGptReferenceImage_FileId value)}) → TResult
inherited
mapOrNull<TResult extends Object?>({TResult? url(ChatGptReferenceImage_Url value)?, TResult? fileId(ChatGptReferenceImage_FileId value)?}) → TResult?
inherited
maybeMap<TResult extends Object?>({TResult url(ChatGptReferenceImage_Url value)?, TResult fileId(ChatGptReferenceImage_FileId value)?, required TResult orElse()}) → TResult
inherited
maybeWhen<TResult extends Object?>({TResult url(String url)?, TResult fileId(String fileId)?, required TResult orElse()}) → TResult
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>({required TResult url(String url), required TResult fileId(String fileId)}) → TResult
inherited
whenOrNull<TResult extends Object?>({TResult? url(String url)?, TResult? fileId(String fileId)?}) → TResult?
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited