GeneratedImage class

Available extensions

Constructors

GeneratedImage({required String mimeType, required String dataBase64, required Uint8List bytes})
const

Properties

bytes Uint8List
final
dataBase64 String
final
hashCode int
The hash code for this object.
no setteroverride
mimeType String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
saveToFile(String path) Future<void>

Available on GeneratedImage, provided by the GeneratedImageX extension

toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override