GenerationOptions class

Constructors

GenerationOptions({double? temperature, double? topP, int? maxTokens, List<String>? stop, Map<String, String>? metadata})
const

Properties

hashCode int
The hash code for this object.
no setteroverride
maxTokens int?
final
metadata Map<String, String>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stop List<String>?
final
temperature double?
final
topP double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

default_() Future<GenerationOptions>