MessagePart_ImageBase64 class abstract

Inheritance

Constructors

MessagePart_ImageBase64({required String mimeType, required String dataBase64})
const
factory

Properties

copyWith → _$$MessagePart_ImageBase64ImplCopyWith<_$MessagePart_ImageBase64Impl>
Create a copy of MessagePart with the given fields replaced by the non-null parameter values.
no setter
dataBase64 String
no setter
hashCode int
The hash code for this object.
no setterinherited
mimeType String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>({required TResult text(MessagePart_Text value), required TResult imageUrl(MessagePart_ImageUrl value), required TResult imageBase64(MessagePart_ImageBase64 value)}) → TResult
inherited
mapOrNull<TResult extends Object?>({TResult? text(MessagePart_Text value)?, TResult? imageUrl(MessagePart_ImageUrl value)?, TResult? imageBase64(MessagePart_ImageBase64 value)?}) → TResult?
inherited
maybeMap<TResult extends Object?>({TResult text(MessagePart_Text value)?, TResult imageUrl(MessagePart_ImageUrl value)?, TResult imageBase64(MessagePart_ImageBase64 value)?, required TResult orElse()}) → TResult
inherited
maybeWhen<TResult extends Object?>({TResult text(String text)?, TResult imageUrl(String url)?, TResult imageBase64(String mimeType, String dataBase64)?, required TResult orElse()}) → TResult
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>({required TResult text(String text), required TResult imageUrl(String url), required TResult imageBase64(String mimeType, String dataBase64)}) → TResult
inherited
whenOrNull<TResult extends Object?>({TResult? text(String text)?, TResult? imageUrl(String url)?, TResult? imageBase64(String mimeType, String dataBase64)?}) → TResult?
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited