Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
map<TResult extends Object?>({required TResult useSystem(ProxyConfig_UseSystem value), required TResult disable(ProxyConfig_Disable value), required TResult custom(ProxyConfig_Custom value)})
→ TResult
-
inherited
-
mapOrNull<TResult extends Object?>({TResult? useSystem(ProxyConfig_UseSystem value)?, TResult? disable(ProxyConfig_Disable value)?, TResult? custom(ProxyConfig_Custom value)?})
→ TResult?
-
inherited
-
maybeMap<TResult extends Object?>({TResult useSystem(ProxyConfig_UseSystem value)?, TResult disable(ProxyConfig_Disable value)?, TResult custom(ProxyConfig_Custom value)?, required TResult orElse()})
→ TResult
-
inherited
-
maybeWhen<TResult extends Object?>({TResult useSystem()?, TResult disable()?, TResult custom(String url)?, required TResult orElse()})
→ TResult
-
inherited
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
-
when<TResult extends Object?>({required TResult useSystem(), required TResult disable(), required TResult custom(String url)})
→ TResult
-
inherited
-
whenOrNull<TResult extends Object?>({TResult? useSystem()?, TResult? disable()?, TResult? custom(String url)?})
→ TResult?
-
inherited