ChatMessage class
- Available extensions
Constructors
-
ChatMessage({required Role role, required List<
MessagePart> content}) -
const
Properties
-
content
→ List<
MessagePart> -
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- role → Role
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addImageBase64(
{required String mimeType, required String dataBase64}) → ChatMessage -
Available on ChatMessage, provided by the ChatMessageX extension
-
addImageUrl(
String url) → ChatMessage -
Available on ChatMessage, provided by the ChatMessageX extension
-
addText(
String text) → ChatMessage -
Available on ChatMessage, provided by the ChatMessageX extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override