ClientConfig class
Constructors
- ClientConfig({required String apiKey, String? chatgptImageApiKey, AuthMode? openaiAuthMode, AuthMode? geminiAuthMode, AuthMode? claudeAuthMode, AuthMode? chatgptImageAuthMode, String? openaiBaseUrl, String? geminiBaseUrl, String? claudeBaseUrl, String? chatgptImageBaseUrl, ProxyConfig? proxy})
-
const
Properties
- apiKey → String
-
final
- chatgptImageApiKey → String?
-
final
- chatgptImageAuthMode → AuthMode?
-
final
- chatgptImageBaseUrl → String?
-
final
- claudeAuthMode → AuthMode?
-
final
- claudeBaseUrl → String?
-
final
- geminiAuthMode → AuthMode?
-
final
- geminiBaseUrl → String?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- openaiAuthMode → AuthMode?
-
final
- openaiBaseUrl → String?
-
final
- proxy → ProxyConfig?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
default_(
) → Future< ClientConfig>